<?php

namespace Drp\SimpleCms\Http\Requests;

use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Foundation\Http\FormRequest;

/**
 * Class ContentRequest
 * @package Drp\SimpleCms
 */
class ContentRequest extends FormRequest implements \Drp\SimpleCms\Contracts\ContentRequest
{
    /**
     * Prepare the input using the given content.
     * Retrieves the before updated closure from the content
     * and calls it using the current request.
     *
     * @param Publishable $content
     * @return array|string
     */
    public function prepareInput(Publishable $content)
    {
        $callback = $content->getCallbackForUpdateRequest($this);

        if ($callback instanceof \Closure) {
            call_user_func($callback, $this);
        }
        return $this->input();
    }

    /**
     * Determine if the user is authorized to make this request.
     *
     * @return boolean
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules()
    {
        return [];
    }

    /**
     * Get custom messages for validator errors.
     *
     * @return array
     */
    public function messages()
    {
        return [];
    }
}
