<?php

namespace Drp\SimpleCms\Policies;

use Drp\SimpleCms\Contracts\CmsUser;
use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Auth\Access\HandlesAuthorization;

/**
 * Class PublishablePolicy
 * @package Drp\SimpleCms
 */
class PublishablePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can publish the study
     *
     * @param  CmsUser $user The logged in user
     * @param Publishable $content
     * @return boolean
     * @SuppressWarnings("unused")
     */
    public function publish(CmsUser $user, Publishable $content = null)
    {
        return $user->hasPublishAccess();
    }

    /**
     * Determine if the given user can manage the review for the study.
     * If the status is already in review the user must have publish access to reject it
     * Otherwise it is a draft and anyone can mark it as review.
     *
     * @param CmsUser $user
     * @param Publishable $content
     * @return boolean
     */
    public function review(CmsUser $user, Publishable $content = null)
    {
        return $content->isInReview() ? $user->hasPublishAccess() : true;
    }

    /**
     * Determine if the given user can delete the study
     *
     * @param  CmsUser $user The logged in user
     * @param Publishable $content
     * @return boolean
     * @SuppressWarnings("unused")
     */
    public function delete(CmsUser $user, Publishable $content = null)
    {
        return $user->hasPublishAccess();
    }
}
