<?php

namespace Drp\SimpleCms;

use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Contracts\Validation\Factory;
use Illuminate\Validation\ValidationException;

/**
 * Class Validator
 * @package Drp\SimpleCms
 */
class Validator
{
    /**
     * @var Factory
     */
    private $validator;

    /**
     * Validator constructor.
     * @param Factory $validator
     */
    public function __construct(Factory $validator)
    {
        $this->validator = $validator;
    }

    /**
     * Validate the study using its rules and messages
     *
     * @param Publishable $content
     * @return boolean
     * @throws ValidationException Thrown if the study fails its validation rules.
     * @SuppressWarnings("unused")
     */
    public function validateContent(Publishable $content)
    {
        //Map each attribute using the models getters
        //this takes advantage of the casting so we
        //get any arrays that are stored as json
        $attributes = collect($content)
            ->map(function ($attribute, $key) use ($content) {
                return $content->$key;
            })->toArray();

        $validator = $this->validator->make($attributes, $content->getRules(), $content->getMessages());

        if ($validator->fails()) {
            flash()->error(trans('validation.error'));
            throw new ValidationException($validator);
        }

        return true;
    }
}
